@@ -211,7 +211,7 @@ class AssistantService:
                     (
                         file_path.name,
                         file,
-                        mimetypes.guess_type(file_path.name)
+                        mimetypes.guess_type(file_path.name)[0]
                         or "application/octet-stream",
                     ),
                 ),
